@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ class Device(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Ip: 该字段表示业务用户对应设备的IP地址，同时**支持IPv4和IPv6**地址的记录；需要与IpType参数配合使用。
         :type Ip: str
         :param Mac: 该字段表示业务用户对应的MAC地址，以方便设备识别与管理；其格式与取值与标准MAC地址一致。
@@ -67,7 +67,7 @@ class Device(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -77,7 +77,7 @@ class ImageModerationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param BizType: 该字段表示策略的具体编号，用于接口调度，在内容安全控制台中可配置。若不传入Biztype参数（留空），则代表采用默认的识别策略；传入则会在审核时根据业务场景采取不同的审核策略。<br>备注：Biztype仅为数字、字母与下划线的组合，长度为3-32个字符；不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype。
         :type BizType: str
         :param DataId: 该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**。
@@ -123,7 +123,7 @@ class ImageModerationRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -133,7 +133,7 @@ class ImageModerationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Suggestion: 该字段用于返回Label标签下的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
         :type Suggestion: str
         :param Label: 该字段用于返回检测结果（LabelResults）中所对应的**优先级最高的恶意标签**，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
@@ -215,191 +215,6 @@ class ImageModerationResponse(AbstractModel):
         self.Extra = params.get("Extra")
         self.FileMD5 = params.get("FileMD5")
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
-
-
-class ImageRecognitionRequest(AbstractModel):
-    """ImageRecognition请求参数结构体
-
-    """
-
-    def __init__(self):
-        """
-        :param Channel: 渠道ID，必须与主调账号一致，由天御分配并与API调用账号绑定
-        :type Channel: int
-        :param CustomAppId: 产品侧腾讯云用户账号AppId
-        :type CustomAppId: str
-        :param BizType: 该字段用于标识业务场景。您可以在内容安全控制台创建对应的ID，配置不同的内容审核策略，通过接口调用，默认不填为0，后端使用默认策略。 -- 该字段暂未开放。
-        :type BizType: str
-        :param DataId: 数据ID，可以由英文字母、数字、下划线、-、@#组成，不超过64个字符
-        :type DataId: str
-        :param FileContent: 数据Base64编码，图片检测接口为图片文件内容，大小不能超过5M
-        :type FileContent: str
-        :param FileUrl: 图片资源访问链接，__与FileContent参数必须二选一输入__
-        :type FileUrl: str
-        :param Interval: 截帧频率，GIF图/长图检测专用，默认值为0，表示只会检测GIF图/长图的第一帧
-        :type Interval: int
-        :param MaxFrames: GIF图/长图检测专用，代表均匀最大截帧数量，默认值为1（即只取GIF第一张，或长图不做切分处理（可能会造成处理超时））。
-        :type MaxFrames: int
-        :param User: 账号相关信息字段，填入后可识别违规风险账号。
-        :type User: :class:`tencentcloud.ims.v20201229.models.User`
-        :param Device: 设备相关信息字段，填入后可识别违规风险设备。
-        :type Device: :class:`tencentcloud.ims.v20201229.models.Device`
-        :param CustomUin: 产品侧腾讯云用户账号Uin
-        :type CustomUin: str
-        :param CustomSubAccountUin: 产品侧腾讯云用户子账号Uin
-        :type CustomSubAccountUin: str
-        :param StreamId: 视频流ID
-        :type StreamId: str
-        """
-        self.Channel = None
-        self.CustomAppId = None
-        self.BizType = None
-        self.DataId = None
-        self.FileContent = None
-        self.FileUrl = None
-        self.Interval = None
-        self.MaxFrames = None
-        self.User = None
-        self.Device = None
-        self.CustomUin = None
-        self.CustomSubAccountUin = None
-        self.StreamId = None
-
-
-    def _deserialize(self, params):
-        self.Channel = params.get("Channel")
-        self.CustomAppId = params.get("CustomAppId")
-        self.BizType = params.get("BizType")
-        self.DataId = params.get("DataId")
-        self.FileContent = params.get("FileContent")
-        self.FileUrl = params.get("FileUrl")
-        self.Interval = params.get("Interval")
-        self.MaxFrames = params.get("MaxFrames")
-        if params.get("User") is not None:
-            self.User = User()
-            self.User._deserialize(params.get("User"))
-        if params.get("Device") is not None:
-            self.Device = Device()
-            self.Device._deserialize(params.get("Device"))
-        self.CustomUin = params.get("CustomUin")
-        self.CustomSubAccountUin = params.get("CustomSubAccountUin")
-        self.StreamId = params.get("StreamId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
-
-
-class ImageRecognitionResponse(AbstractModel):
-    """ImageRecognition返回参数结构体
-
-    """
-
-    def __init__(self):
-        """
-        :param Suggestion: 建议您拿到判断结果后的执行操作。
-建议值，Block：建议屏蔽，Review：建议复审，Pass：建议通过
-        :type Suggestion: str
-        :param Label: 恶意标签，Normal：正常，Porn：色情，Abuse：谩骂，Ad：广告，Custom：自定义图片。
-以及令人反感、不安全或不适宜的内容类型。
-        :type Label: str
-        :param SubLabel: 子标签名称，如色情--性行为；当未命中子标签时，返回空字符串；
-        :type SubLabel: str
-        :param Score: 机器判断当前分类的置信度，取值范围：0.00~100.00。分数越高，表示越有可能属于当前分类。
-（如：色情 99.99，则该样本属于色情的置信度非常高。）
-        :type Score: int
-        :param LabelResults: 智能模型的识别结果，包括涉黄、广告等令人反感、不安全或不适宜的内容类型识别结果。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type LabelResults: list of LabelResult
-        :param ObjectResults: 物体检测模型的审核结果，包括实体、广告台标/二维码等物体坐标信息与内容审核信息。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type ObjectResults: list of ObjectResult
-        :param OcrResults: OCR识别后的文本识别结果，包括文本所处图片的OCR坐标信息以及图片文本的识别结果。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type OcrResults: list of OcrResult
-        :param LibResults: 基于图片风险库识别的结果。
-风险库包括不安全黑库与正常白库的结果。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type LibResults: list of LibResult
-        :param DataId: 请求参数中的DataId。
-        :type DataId: str
-        :param BizType: 您在入参时所填入的Biztype参数。 -- 该字段暂未开放。
-        :type BizType: str
-        :param Extra: 扩展字段，用于特定信息返回，不同客户/Biztype下返回信息不同。
-注意：此字段可能返回 null，表示取不到有效值。
-注意：此字段可能返回 null，表示取不到有效值。
-        :type Extra: str
-        :param FileMD5: 图片MD5值
-        :type FileMD5: str
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.Suggestion = None
-        self.Label = None
-        self.SubLabel = None
-        self.Score = None
-        self.LabelResults = None
-        self.ObjectResults = None
-        self.OcrResults = None
-        self.LibResults = None
-        self.DataId = None
-        self.BizType = None
-        self.Extra = None
-        self.FileMD5 = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        self.Suggestion = params.get("Suggestion")
-        self.Label = params.get("Label")
-        self.SubLabel = params.get("SubLabel")
-        self.Score = params.get("Score")
-        if params.get("LabelResults") is not None:
-            self.LabelResults = []
-            for item in params.get("LabelResults"):
-                obj = LabelResult()
-                obj._deserialize(item)
-                self.LabelResults.append(obj)
-        if params.get("ObjectResults") is not None:
-            self.ObjectResults = []
-            for item in params.get("ObjectResults"):
-                obj = ObjectResult()
-                obj._deserialize(item)
-                self.ObjectResults.append(obj)
-        if params.get("OcrResults") is not None:
-            self.OcrResults = []
-            for item in params.get("OcrResults"):
-                obj = OcrResult()
-                obj._deserialize(item)
-                self.OcrResults.append(obj)
-        if params.get("LibResults") is not None:
-            self.LibResults = []
-            for item in params.get("LibResults"):
-                obj = LibResult()
-                obj._deserialize(item)
-                self.LibResults.append(obj)
-        self.DataId = params.get("DataId")
-        self.BizType = params.get("BizType")
-        self.Extra = params.get("Extra")
-        self.FileMD5 = params.get("FileMD5")
-        self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class LabelDetailItem(AbstractModel):
@@ -408,7 +223,7 @@ class LabelDetailItem(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 该字段用于返回识别对象的ID以方便识别和区分。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Id: int
@@ -433,7 +248,7 @@ class LabelDetailItem(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -443,7 +258,7 @@ class LabelResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scene: 该字段用于返回模型识别出的场景结果，如广告、色情、有害内容等场景。
         :type Scene: str
         :param Suggestion: 该字段用于返回针对当前恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
@@ -483,7 +298,7 @@ class LabelResult(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -493,7 +308,7 @@ class LibDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 该字段用于返回识别对象的ID以方便识别和区分。
         :type Id: int
         :param LibId: 该字段**仅当Label为Custom：自定义关键词时该参数有效**,用于返回自定义库的ID，以方便自定义库管理和配置。
@@ -533,7 +348,7 @@ class LibDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -543,7 +358,7 @@ class LibResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scene: 该字段表示模型的场景识别结果，默认取值为Similar。
         :type Scene: str
         :param Suggestion: 该字段用于返回后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
@@ -584,7 +399,7 @@ class LibResult(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -594,7 +409,7 @@ class Location(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param X: 该参数用于返回检测框**左上角位置的横坐标**（x）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
         :type X: float
         :param Y: 该参数用于返回检测框**左上角位置的纵坐标**（y）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
@@ -624,7 +439,7 @@ class Location(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -634,7 +449,7 @@ class ObjectDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Id: 该参数用于返回识别对象的ID以方便识别和区分。
         :type Id: int
         :param Name: 该参数用于返回命中的实体标签。
@@ -645,12 +460,15 @@ class ObjectDetail(AbstractModel):
         :type Score: int
         :param Location: 该字段用于返回实体检测框的坐标位置（左上角xy坐标、长宽、旋转角度）以方便快速定位实体的相关信息。
         :type Location: :class:`tencentcloud.ims.v20201229.models.Location`
+        :param SubLabel: 该参数用于返回命中的实体二级标签。
+        :type SubLabel: str
         """
         self.Id = None
         self.Name = None
         self.Value = None
         self.Score = None
         self.Location = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -661,12 +479,13 @@ class ObjectDetail(AbstractModel):
         if params.get("Location") is not None:
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -676,7 +495,7 @@ class ObjectResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scene: 该字段用于返回实体识别出的实体场景结果，如二维码、logo、图片OCR等场景。
         :type Scene: str
         :param Suggestion: 该字段用于返回针对当前恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
@@ -722,7 +541,7 @@ class ObjectResult(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -732,7 +551,7 @@ class OcrResult(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Scene: 该字段表示识别场景，取值默认为OCR（图片OCR识别）。
         :type Scene: str
         :param Suggestion: 该字段用于返回优先级最高的恶意标签对应的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
@@ -776,7 +595,7 @@ class OcrResult(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -786,7 +605,7 @@ class OcrTextDetail(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Text: 该字段用于返回OCR识别出的文本内容。<br>备注：OCR文本识别上限在**5000字节内**。
         :type Text: str
         :param Label: 该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告，**Custom**：自定义违规；以及其他令人反感、不安全或不适宜的内容类型。
@@ -803,6 +622,8 @@ class OcrTextDetail(AbstractModel):
         :type Location: :class:`tencentcloud.ims.v20201229.models.Location`
         :param Rate: 该参数用于返回OCR文本识别结果的置信度，取值在**0**（**置信度最低**）-**100**（**置信度最高**），越高代表对应图像越有可能是识别出的文字；如：*你好 99*，则表明OCR识别框内的文字大概率是”你好“。
         :type Rate: int
+        :param SubLabel: 该字段用于返回检测结果所对应的恶意二级标签。
+        :type SubLabel: str
         """
         self.Text = None
         self.Label = None
@@ -812,6 +633,7 @@ class OcrTextDetail(AbstractModel):
         self.Score = None
         self.Location = None
         self.Rate = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -825,12 +647,13 @@ class OcrTextDetail(AbstractModel):
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
         self.Rate = params.get("Rate")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -840,7 +663,7 @@ class User(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param UserId: 该字段表示业务用户ID,填写后，系统可根据账号过往违规历史优化审核结果判定，有利于存在可疑违规风险时的辅助判断。<br>
 备注：该字段可传入微信openid、QQopenid、字符串等账号信息，与账号类别参数（AccountType）配合使用可确定唯一账号。
         :type UserId: str
@@ -892,5 +715,5 @@ class User(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
